/* redir.h - header file for redir.c */
/* $Id: redir.h,v 2.1 1998/08/11 17:37:47 caleishm Exp caleishm $  */
/* Chris Leishman, Trevor Cohn.  Ormond College student IT department, 1998.*/

#ifndef REDIR_H
#define REDIR_H


extern void redirect(item *, char *, char *);

#endif
